package com.community.huiju.service;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.exception.WisdomException;
import org.springframework.web.multipart.MultipartFile;

import java.util.Map;

/**
 * 海康硬件接口
 */
public interface HkHardwareServiceI {

    default void checkResult(String json) {
        JSONObject jsonObject = JSONObject.parseObject(json);
        Integer errorCode = jsonObject.getInteger("errorCode");
        if (errorCode != 0) {
            throw new WisdomException(jsonObject.getString("errorMessage"));
        }
    }

    /**
     * 下发门口机权限
     *
     *  {
     *      "authName":"权限组",
     *      "personIds":[人员海康ID...],
     *      "secret":"服务器secret",
     *      "appkey":"服务器appkey",
     *      "openapi_ip_port_http":"服务器地址",
     *      "opUserUuid":"服务器操作人员UUID",
     *      "longNums":"门口机(可视对讲)编号"
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean downloadDoorPermissions(String jsonString);

    /**
     * 下发门口机人脸
     *
     *  {
     *      "secret":"服务器secret",
     *      "appkey":"服务器appkey",
     *      "openapi_ip_port_http":"服务器地址",
     *      "opUserUuid":"服务器操作人员UUID",
     *      "opType": 1, // 表示下发
     *      "personIds":"人员海康ID",
     *      "longNums":"门口机(可视对讲)编号"
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean downloadDoorFace(String jsonString);

    /**
     *
     * 异步反控开门 (远程开门(可视对讲，门口机))
     *
     *  {
     *      "longNums":"门口机编号",
     *      "openapi_ip_port_http":"服务器地址",
     *      "secret":"服务器secret",
     *      "appkey":"服务器appkey",
     *      "opUserUuid":"服务器操作人员UUID"
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean syncControl(String jsonString);

    /**
     * 删除门口机权限
     * @return
     */
    ResponseBean deleteDoorPermissions(String jsonString);

    /**
     * 下发门禁权限
     *
     *  {
     *      "personIds":"人员海康ID",
     *      "doorUuids":"门禁点UUID",
     *      "secret":"服务器secret",
     *      "appkey":"服务器appkey",
     *      "openapi_ip_port_http":"服务器操地址",
     *      "opUserUuid":"服务器操作人员UUID"
     *
     *
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean downloadEntranceGuardPermissions(String jsonString);

    /**
     * 下发门禁人脸
     *
     *  {
     *      "secret":"服务器secret",
     *      "appkey":"服务器appkey",
     *      "openapi_ip_port_http":"服务器操地址",
     *      "opUserUuid":"服务器操作人员UUID",
     *      "personIds":"人员海康ID",
     *      "deviceUuids":"门禁设备UUID",
     *      "type":"1"
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean downloadEntranceGuardFace(String jsonString);

    /**
     * 删除门禁权限
     * @return
     */
    ResponseBean deleteEntranceGuardPermissions(String jsonString);


    /**
     * 添加人脸
     *
     *  {
     *      "doorPermissions":{ // 下发门口机权限(可视对讲)
     *          "authName":"权限组",
     *          "personIds":[人员海康ID...],
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "longNums":"门口机(可视对讲)编号"
     *      },
     *      "doorFace": { // 下发门口机人脸权限
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "opType": 1, // 表示下发
     *          "personIds":"人员海康ID",
     *          "longNums":"门口机(可视对讲)编号"
     *      },
     *      "entranceGuardPermissions":{ // 下发门禁权限
     *          "personIds":"人员海康ID",
     *          "doorUuids":"门禁点UUID",
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器操地址",
     *          "opUserUuid":"服务器操作人员UUID"
     *      },
     *      "entranceGuardFace":{ // 下发门禁人脸权限
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器操地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "personIds":"人员海康ID",
     *          "deviceUuids":"门禁设备UUID",
     *          "type":"1"
     *      },
     *      "person":{
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器操地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "personId":"人员海康ID",
     *          "personNo":"人员海康编号",
     *          "personName":"人员名称",
     *          //"facePhoto":"人脸图片",
     *          "cardNo":"卡号"
     *      }
     *  }
     *
     *
     * @param jsonString
     * @return
     */
    ResponseBean addFace(MultipartFile faceImg, String jsonString);

    /**
     * 修改人脸
     *
     *
     *  {
     *      "doorFace": { // 下发门口机人脸权限
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "opType": 1, // 表示下发
     *          "personIds":"人员海康ID",
     *          "longNums":"门口机(可视对讲)编号"
     *      },
     *      "entranceGuardFace":{ // 下发门禁人脸权限
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器操地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "personIds":"人员海康ID",
     *          "deviceUuids":"门禁设备UUID",
     *          "type":"1"
     *      },
     *      "person":{
     *          "secret":"服务器secret",
     *          "appkey":"服务器appkey",
     *          "openapi_ip_port_http":"服务器操地址",
     *          "opUserUuid":"服务器操作人员UUID",
     *          "personId":"人员海康ID",
     *          "personNo":"人员海康编号",
     *          "personName":"人员名称",
     *          //"facePhoto":"人脸图片",
     *          "cardNo":"卡号"
     *      }
     *  }
     *
     *
     * @param jsonString
     * @return
     */
    ResponseBean updateFace(MultipartFile faceImg,String jsonString);

    /**
     * 删除人脸
     * @param jsonString
     * @return
     */
    ResponseBean deleteFace(String jsonString);

    /**
     * 添加人员
     *
     *  { // 人员信息
     *          "openapi_ip_port_http":"服务器地址",
     *          "appkey":"服务器appkey",
     *          "secret":"服务器secret",
     *          "opUserUuid":"操作人员UUID",
     *          "personNo":"人员编号",
     *          "personName":"人员姓名",
     *          "remark":"手机号",
     *          "deptUuid","部门uuid"
     *          "card":"卡号",
     *          "expirationTime": 开卡有效期, 值为 0 表示 20 年
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean addPerson(String jsonString);

    /**
     * 修改人员
     *
     *  { // 人员信息
     *          "openapi_ip_port_http":"服务器地址",
     *          "appkey":"服务器appkey",
     *          "secret":"服务器secret",
     *          "opUserUuid":"操作人员UUID",
     *          "personNo":"人员编号",
     *          "personName":"人员姓名",
     *          "remark":"手机号",
     *          "deptUuid":"部门uuid",
     *          "personId":"人员海康ID"
     *
     *  }
     *
     * @param jsonString
     * @return
     */
    ResponseBean updatePerson(String jsonString);

    /**
     * 删除人员
     * @param jsonString
     * @return
     */
    ResponseBean deletePerson(String jsonString);


}
